"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployExecutor = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@nx-extend/core");
const path_1 = require("path");
function deployExecutor(options, context) {
    var _a, _b;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { functionName, region, trigger = 'http', triggerValue = null, triggerEvent = null, runtime = 'nodejs14', allowUnauthenticated = true, envVarsFile = null, maxInstances = 10, project = null, memory = '128MB', serviceAccount = null, entryPoint = null, retry = false, ingressSettings = null, egressSettings = null, securityLevel = null } = options;
        if (triggerValue && trigger === 'http') {
            throw new Error('"triggerValue" is not accepted when trigger is "http"!');
        }
        const { targets } = context.workspace.projects[context.projectName];
        return core_1.execCommand(core_1.buildCommand([
            'gcloud functions deploy',
            functionName,
            `--trigger-${trigger}${triggerValue ? `=${triggerValue}` : ''}`,
            triggerEvent && `--trigger-event=${triggerEvent}`,
            `--runtime=${runtime}`,
            `--memory=${memory}`,
            `--region=${region}`,
            entryPoint && `--entry-point=${entryPoint}`,
            envVarsFile && `--env-vars-file=${envVarsFile}`,
            retry && `--retry`,
            ingressSettings && `--ingress-settings=${ingressSettings}`,
            egressSettings && `--egress-settings=${egressSettings}`,
            securityLevel && `--security-level=${securityLevel}`,
            `--source=${path_1.join(context.root, (_b = (_a = targets === null || targets === void 0 ? void 0 : targets.build) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.outputPath.toString())}`,
            `--max-instances=${maxInstances}`,
            allowUnauthenticated && '--allow-unauthenticated',
            serviceAccount && `--service-account=${serviceAccount}`,
            project && `--project=${project}`
        ]));
    });
}
exports.deployExecutor = deployExecutor;
exports.default = deployExecutor;
//# sourceMappingURL=deploy.impl.js.map